TempoRevmEvm

Type Alias TempoRevmEvm 

pub type TempoRevmEvm<'db, I> = TempoEvm<&'db mut dyn DatabaseExt<TempoEvmFactory, Error = DatabaseError>, I>;

Aliased Type

pub struct TempoRevmEvm<'db, I> {
    pub inner: Evm<Context<TempoBlockEnv, TempoTxEnv, CfgEnv<TempoHardfork>, &'db mut dyn DatabaseExt<TempoEvmFactory, Error = DatabaseError>>, I, EthInstructions<EthInterpreter, Context<TempoBlockEnv, TempoTxEnv, CfgEnv<TempoHardfork>, &'db mut dyn DatabaseExt<TempoEvmFactory, Error = DatabaseError>>>, PrecompilesMap, EthFrame>,
    pub skip_valid_after_check: bool,
    pub skip_liquidity_check: bool,
    /* private fields */
}

Fields

inner: Evm<Context<TempoBlockEnv, TempoTxEnv, CfgEnv<TempoHardfork>, &'db mut dyn DatabaseExt<TempoEvmFactory, Error = DatabaseError>>, I, EthInstructions<EthInterpreter, Context<TempoBlockEnv, TempoTxEnv, CfgEnv<TempoHardfork>, &'db mut dyn DatabaseExt<TempoEvmFactory, Error = DatabaseError>>>, PrecompilesMap, EthFrame>

Inner EVM type.

skip_valid_after_check: bool

When true, skips the valid_after time-window check during validation.

The transaction pool sets this because it intentionally accepts transactions with a future valid_after (queued until executable).

skip_liquidity_check: bool

When true, skips the AMM liquidity check in collect_fee_pre_tx.

The transaction pool sets this because it performs its own liquidity validation against a cached view of the AMM state.

Layout

Note: Unable to compute type layout, possibly due to this type having generic parameters. Layout can only be computed for concrete, fully-instantiated types.