Type Alias EthRevmEvm
pub type EthRevmEvm<'db, I> = Evm<Context<BlockEnv, TxEnv, CfgEnv, &'db mut dyn DatabaseExt<EthEvmFactory, Error = DatabaseError>>, I, EthInstructions<EthInterpreter, Context<BlockEnv, TxEnv, CfgEnv, &'db mut dyn DatabaseExt<EthEvmFactory, Error = DatabaseError>>>, PrecompilesMap, EthFrame>;Aliased Type
pub struct EthRevmEvm<'db, I> {
pub ctx: Context<BlockEnv, TxEnv, CfgEnv, &'db mut dyn DatabaseExt<EthEvmFactory, Error = DatabaseError>>,
pub inspector: I,
pub instruction: EthInstructions<EthInterpreter, Context<BlockEnv, TxEnv, CfgEnv, &'db mut dyn DatabaseExt<EthEvmFactory, Error = DatabaseError>>>,
pub precompiles: PrecompilesMap,
pub frame_stack: FrameStack<EthFrame>,
}Fields
ctx: Context<BlockEnv, TxEnv, CfgEnv, &'db mut dyn DatabaseExt<EthEvmFactory, Error = DatabaseError>>context_interface::ContextTr of the EVM it is used to fetch data from database.
inspector: IInspector of the EVM it is used to inspect the EVM. Its trait are defined in revm-inspector crate.
instruction: EthInstructions<EthInterpreter, Context<BlockEnv, TxEnv, CfgEnv, &'db mut dyn DatabaseExt<EthEvmFactory, Error = DatabaseError>>>Instructions provider of the EVM it is used to execute instructions.
InstructionProvider trait is defined in revm-handler crate.
precompiles: PrecompilesMapPrecompile provider of the EVM it is used to execute precompiles.
PrecompileProvider trait is defined in revm-handler crate.
frame_stack: FrameStack<EthFrame>Frame that is going to be executed.
Layout
Note: Unable to compute type layout, possibly due to this type having generic parameters. Layout can only be computed for concrete, fully-instantiated types.